Learn R Programming

quantreg (version 3.04)

summary.rq: Summary method for Quantile Regression

Description

Returns a summary list for a quantile regression fit. A null value will be returned if printing is invoked.

Usage

summary.rq(object, se="nid", covariance=T, hs = T, ...)

Arguments

object
This is an object of class "rq" produced by a call to rq().
se
specifies the method used to compute standard standard errors. There are currently three available methods:
  1. "iid"which presumes that the errors are iid and computes an estimate of the asymptotic covariance matrix as i
covariance
logical flag to indicate whether the full covariance matrix of the estimated parameters should be returned.
hs
Use Hall Sheather bandwidth for sparsity estimation If false revert to Bofinger bandwidth.
...
Optional arguments to summary

Value

  • a list is returned with the following components
  • coefficientsa p by 4 matrix consisting of the coefficients, their estimated standard errors, their t-statistics, and their associated p-values.
  • covthe estimated covariance matrix for the coefficients in the model, provided that cov=T in the called sequence.
  • Hinvinverse of the estimated Hessian matrix returned if cov=T and se != "iid".
  • JOuter product of gradient matrix returned if cov=T and se != "iid". The Huber sandwich is cov = Hinv %*% J %*% Hinv.

References

Koenker, R. (2000) Quantile Regression.

See Also

rq bandwidth.rq

Examples

Run this code
data(stackloss)
y <- stack.loss
x <- stack.x
summary(rq(y ~ x, method="fn")) # Compute se's for fit using "nid" method.
summary(rq(y ~ x, ci=F),se="ker")
# default "br" alg, and compute kernel method se's

Run the code above in your browser using DataLab